@@ -2,6 +2,9 @@
     begin                : Sat Feb 16 2002
     copyright            : (C) 2002 - 2004 by Scott Wheeler
     email                : wheeler@kde.org
+
+    copyright            : (C) 2008 by Michael Pyne
+    email                : michael.pyne@kdemail.net
 ***************************************************************************/
 
 /***************************************************************************
@@ -14,6 +17,7 @@
  ***************************************************************************/
 
 #include "playlist.h"
+#include "juk-exception.h"
 
 #include <kconfig.h>
 #include <kapplication.h>
@@ -254,7 +258,7 @@ Playlist::SharedSettings::SharedSettings()
     KConfigGroup config(KGlobal::config(), "PlaylistShared");
 
     bool resizeColumnsManually = config.readEntry("ResizeColumnsManually", false);
-    action<KToggleAction>("resizeColumnsManually")->setChecked(resizeColumnsManually);
+    action("resizeColumnsManually")->setChecked(resizeColumnsManually);
 
     // Preallocate spaces so we don't need to check later.
     m_columnsVisible.fill(true, PlaylistItem::lastColumn() + 1);
@@ -278,8 +282,8 @@ Playlist::SharedSettings::SharedSettings()
         // Convert the int list into a bool list.
 
         m_columnsVisible.fill(false);
-        foreach(int column, l)
-            m_columnsVisible[column] = true;
+        for(int i = 0; i < l.size() && i < m_columnsVisible.size(); ++i)
+            m_columnsVisible[i] = bool(l[i]);
     }
 
     m_inlineCompletion = KGlobalSettings::Completion(
@@ -406,7 +410,7 @@ Playlist::Playlist(PlaylistCollection *collection, bool delaySetup) :
     setup();
 
     if(!delaySetup)
-        collection->setupPlaylist(this, "midi");
+        collection->setupPlaylist(this, "audio-midi");
 }
 
 Playlist::~Playlist()
@@ -1262,6 +1266,10 @@ void Playlist::read(QDataStream &s)
     s >> m_playlistName
       >> m_fileName;
 
+    // m_fileName is probably empty.
+    if(m_playlistName.isEmpty())
+        throw BICStreamException();
+
     QStringList files;
     s >> files;
 
@@ -1269,13 +1277,17 @@ void Playlist::read(QDataStream &s)
 
     m_blockDataChanged = true;
 
-    for(QStringList::ConstIterator it = files.begin(); it != files.end(); ++it)
-        after = createItem(FileHandle(*it), after, false);
+    foreach(QString file, files) {
+        if(file.isEmpty())
+            throw BICStreamException();
+
+        after = createItem(FileHandle(file), after, false);
+    }
 
     m_blockDataChanged = false;
 
     dataChanged();
-    m_collection->setupPlaylist(this, "midi");
+    m_collection->setupPlaylist(this, "audio-midi");
 }
 
 void Playlist::viewportPaintEvent(QPaintEvent *pe)
